ApiCallResponse class

Constructors

ApiCallResponse(dynamic jsonBody, Map<String, String> headers, int statusCode, {Response? response})
const

Properties

bodyText → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
jsonBody → dynamic
final
response → Response?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
succeeded → bool
no setter

Methods

getHeader(String headerName) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromCloudCallResponse(Map<String, dynamic> response) → ApiCallResponse
fromHttpResponse(Response response, bool returnBody, bool decodeUtf8) → ApiCallResponse