LevelUpgradeModel class

Inheritance

Constructors

LevelUpgradeModel()

Properties

disposeOnWidgetDisposal ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateOnChange ↔ bool
getter/setter pairinherited

Methods

dispose() → void
override
initState(BuildContext context) → void
override
maybeDispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpdate() → void
inherited
setOnUpdate({bool updateOnChange = false, required VoidCallback onUpdate}) → GajModel
inherited
toString() → String
A string representation of this object.
inherited
updatePage(VoidCallback callback) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited