TransactionReceiptModel class

Inheritance

Constructors

TransactionReceiptModel()

Properties

apiResultb7a ↔ ApiCallResponse?
State fields for stateful widgets in this component.
getter/setter pair
baseUrl ↔ String?
getter/setter pair
dateFilter ↔ String?
Local state fields for this component.
getter/setter pair
disposeOnWidgetDisposal ↔ bool
getter/setter pairinherited
endDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDaate ↔ DateTime?
getter/setter pair
updateOnChange ↔ bool
getter/setter pairinherited

Methods

dispose() → void
override
initState(BuildContext context) → void
Initialization and disposal methods.
override
maybeDispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onUpdate() → void
inherited
setOnUpdate({bool updateOnChange = false, required VoidCallback onUpdate}) → GajModel
inherited
toString() → String
A string representation of this object.
inherited
updatePage(VoidCallback callback) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited